==> ChinAPIs_0.1.0.tar.gz: ChinAPIs/R/get_china_energy_use.R <==
# ChinAPIs - Access Chinese Data via APIs and Curated Datasets
# Version 0.1.0
# Copyright (c) 2025 Renzo Caceres Rossi
# Licensed under the MIT License.
# See the LICENSE file in the root directory for full license text.


#' Get China's Energy Use (kg of oil equivalent per capita) from World Bank
#'
#' @description
#' Retrieves China's energy use per capita, measured in kilograms of oil equivalent,
#' for the years 2010 to 2022 using the World Bank Open Data API.
#' The indicator used is \code{EG.USE.PCAP.KG.OE}.
#'
#' @return A tibble with the following columns:
#' \itemize{
#'   \item \code{indicator}: Indicator name (e.g., "Energy use (kg of oil equivalent per capita)")
#'   \item \code{country}: Country name ("China")
#'   \item \code{year}: Year of the data (integer)
#'   \item \code{value}: Energy use in kilograms of oil equivalent per capita
#' }
#'
#' @details
#' This function sends a GET request to the World Bank API.
#' If the API request fails or returns an error status code,
#' the function returns \code{NULL} with an informative message.
#'
#' @note Requires internet connection.
#'
#' @source World Bank Open Data API: \url{https://data.worldbank.org/indicator/EG.USE.PCAP.KG.OE}
#'
#' @examples
#' if (interactive()) {
#'   get_china_energy_use()
#' }
#'
#' @seealso \code{\link[httr]{GET}}, \code{\link[jsonlite]{fromJSON}}, \code{\link[dplyr]{as_tibble}}
#'
#' @importFrom httr GET content
#' @importFrom jsonlite fromJSON
#' @importFrom dplyr as_tibble
#'
#' @export
get_china_energy_use <- function() {
  url <- "https://api.worldbank.org/v2/country/CHN/indicator/EG.USE.PCAP.KG.OE?format=json&date=2010:2022&per_page=100"
  res <- httr::GET(url)
  if (res$status_code != 200) {
    message(paste("Error: status", res$status_code))
    return(NULL)
  }
  content <- jsonlite::fromJSON(httr::content(res, "text", encoding = "UTF-8"))
  if (length(content) < 2 || is.null(content[[2]])) {
    message("No data returned from the World Bank API.")
    return(NULL)
  }
  data <- content[[2]]
  df <- dplyr::as_tibble(data.frame(
    indicator = data$indicator$value,
    country = data$country$value,
    year = as.integer(data$date),
    value = data$value
  ))
  return(df)
}

==> ChinAPIs_0.1.1.tar.gz: ChinAPIs/R/get_china_energy_use.R <==
# ChinAPIs - Access Chinese Data via APIs and Curated Datasets
# Version 0.1.1
# Copyright (c) 2026 Renzo Caceres Rossi
# Licensed under the MIT License.
# See the LICENSE file in the root directory for full license text.


#' Get China's Energy Use (kg of oil equivalent per capita) from World Bank
#'
#' @description
#' Retrieves China's energy use per capita, measured in kilograms of oil equivalent,
#' for the years 2010 to 2022 using the World Bank Open Data API.
#' The indicator used is \code{EG.USE.PCAP.KG.OE}.
#'
#' @return A tibble with the following columns:
#' \itemize{
#'   \item \code{indicator}: Indicator name (e.g., "Energy use (kg of oil equivalent per capita)")
#'   \item \code{country}: Country name ("China")
#'   \item \code{year}: Year of the data (integer)
#'   \item \code{value}: Energy use in kilograms of oil equivalent per capita
#' }
#'
#' @details
#' This function sends a GET request to the World Bank API.
#' If the API request fails or returns an error status code,
#' the function returns \code{NULL} with an informative message.
#'
#' @note Requires internet connection.
#'
#' @source World Bank Open Data API: \url{https://data.worldbank.org/indicator/EG.USE.PCAP.KG.OE}
#'
#' @examples
#' if (interactive()) {
#'   get_china_energy_use()
#' }
#'
#' @seealso \code{\link[httr]{GET}}, \code{\link[jsonlite]{fromJSON}}, \code{\link[dplyr]{as_tibble}}
#'
#' @importFrom httr GET content
#' @importFrom jsonlite fromJSON
#' @importFrom dplyr as_tibble
#'
#' @export
get_china_energy_use <- function() {

  url <- "https://api.worldbank.org/v2/country/CHN/indicator/EG.USE.PCAP.KG.OE?format=json&date=2010:2022&per_page=100"

  res <- tryCatch(
    httr::GET(url, httr::timeout(10)),
    error = function(e) {
      message("World Bank API request failed: ", conditionMessage(e))
      return(NULL)
    }
  )

  if (is.null(res)) {
    return(NULL)
  }

  if (httr::status_code(res) != 200) {
    message("World Bank API returned status: ", httr::status_code(res))
    return(NULL)
  }

  txt <- tryCatch(
    httr::content(res, as = "text", encoding = "UTF-8"),
    error = function(e) {
      message("Failed to retrieve content from API.")
      return(NULL)
    }
  )

  if (is.null(txt) || txt == "") {
    message("Empty response from World Bank API.")
    return(NULL)
  }

  content <- tryCatch(
    jsonlite::fromJSON(txt),
    error = function(e) {
      message("Failed to parse JSON response.")
      return(NULL)
    }
  )

  if (length(content) < 2 || is.null(content[[2]])) {
    message("No data returned from the World Bank API.")
    return(NULL)
  }

  data <- content[[2]]

  df <- dplyr::as_tibble(data.frame(
    indicator = data$indicator$value,
    country   = data$country$value,
    year      = as.integer(data$date),
    value     = as.numeric(data$value)
  ))

  return(df)
}
